@@ -105,7 +105,7 @@ class BatteryChecker(IntervalModule):
     This class uses the /sys/class/power_supply/…/uevent interface to check for the
     battery status
 
-    Available formatters:
+    .. rubric:: Available formatters
 
     * `{remaining}` — remaining time for charging or discharging, uses TimeWrapper formatting, default format is `%E%h:%M`
     * `{percentage}` — battery percentage relative to the last full value
@@ -131,7 +131,9 @@ class BatteryChecker(IntervalModule):
         ("charging_color", "The charging color"),
         ("critical_color", "The critical color"),
         ("not_present_color", "The not present color."),
+        ("no_text_full", "Don't display text when battery is full - 100%"),
     )
+
     battery_ident = "BAT0"
     format = "{status} {remaining}"
     status = {
@@ -150,6 +152,7 @@ class BatteryChecker(IntervalModule):
     charging_color = "#00ff00"
     critical_color = "#ff0000"
     not_present_color = "#ffffff"
+    no_text_full = False
 
     path = None
 
@@ -170,6 +173,12 @@ class BatteryChecker(IntervalModule):
                 "color": self.not_present_color,
             }
             return
+        if self.no_text_full:
+            if battery.status() == "Full":
+                self.output = {
+                    "full_text": ""
+                }
+                return
 
         fdict = {
             "battery_ident": self.battery_ident,
