@@ -7,7 +7,7 @@ class Mem(IntervalModule):
     """
     Shows memory load
 
-    Available formatters:
+    .. rubric:: Available formatters
 
     * {avail_mem}
     * {percent_used_mem}
@@ -26,8 +26,6 @@ class Mem(IntervalModule):
     alert_percentage = 80
     round_size = 1
 
-    
-
     settings = (
         ("format", "format string used for output."),
         ("divisor",
@@ -54,16 +52,15 @@ class Mem(IntervalModule):
             color = self.warn_color
         else:
             color = self.color
-            
+
         cdict = {
-                "used_mem":used / self.divisor,
-                "avail_mem":memory_usage.available / self.divisor,
-                "total_mem":memory_usage.total / self.divisor,
-                "percent_used_mem":memory_usage.percent,
+            "used_mem": used / self.divisor,
+            "avail_mem": memory_usage.available / self.divisor,
+            "total_mem": memory_usage.total / self.divisor,
+            "percent_used_mem": memory_usage.percent,
         }
         round_dict(cdict, self.round_size)
 
-
         self.output = {
             "full_text": self.format.format(**cdict),
             "color": color
