@@ -2,7 +2,7 @@ import threading
 import math
 
 from i3pystatus import Module
-from gi.repository import GLib
+from gi.repository import Playerctl, GLib
 
 
 class Spotify(Module):
